import { Body, Controller, Patch, UseGuards } from '@nestjs/common';
import { ApiBearerAuth, ApiTags } from '@nestjs/swagger';
import { IJwtPayload } from '~/auth/interfaces';
import { AuthenticatedUser } from '~/common/decorators';
import { AccessTokenGuard } from '~/common/guards';
import { ResponseFactory } from '~/core/utils';
import { UpdateCustomerRequestDto, UpdateNotificationsSettingsRequestDto } from '../dtos/request';
import { CustomerResponseDto, NotificationSettingsResponseDto } from '../dtos/response';
import { CustomerService } from '../services';

@Controller('customers')
@ApiTags('Customers')
@ApiBearerAuth()
@UseGuards(AccessTokenGuard)
export class CustomerController {
  constructor(private readonly customerService: CustomerService) {}

  @Patch('')
  async updateCustomer(@AuthenticatedUser() { sub }: IJwtPayload, @Body() body: UpdateCustomerRequestDto) {
    const customer = await this.customerService.updateCustomer(sub, body);

    return ResponseFactory.data(new CustomerResponseDto(customer));
  }

  @Patch('settings/notifications')
  async updateNotificationSettings(
    @AuthenticatedUser() { sub }: IJwtPayload,
    @Body() body: UpdateNotificationsSettingsRequestDto,
  ) {
    const notificationSettings = await this.customerService.updateNotificationSettings(sub, body);

    return ResponseFactory.data(new NotificationSettingsResponseDto(notificationSettings));
  }
}
