import { Column, Entity, OneToOne, PrimaryGeneratedColumn, UpdateDateColumn } from 'typeorm';
import { User } from '~/auth/entities';
import { Junior } from '~/junior/entities';
import { DocumentType } from '../enums';

@Entity('documents')
export class Document {
  @PrimaryGeneratedColumn('uuid')
  id!: string;

  @Column({ type: 'varchar', length: 255 })
  name!: string;

  @Column({ type: 'varchar', length: 255 })
  extension!: string;

  @Column({ type: 'varchar', length: 255 })
  documentType!: DocumentType;

  @OneToOne(() => User, (user) => user.profilePicture, { onDelete: 'CASCADE' })
  user!: User;

  @OneToOne(() => Junior, (junior) => junior.civilIdFront, { onDelete: 'CASCADE' })
  juniorCivilIdFront!: User;

  @OneToOne(() => Junior, (junior) => junior.civilIdBack, { onDelete: 'CASCADE' })
  juniorCivilIdBack!: User;

  @UpdateDateColumn({ name: 'updated_at', type: 'timestamp', default: () => 'CURRENT_TIMESTAMP' })
  updatedAt!: Date;

  @Column({ name: 'created_at', type: 'timestamp', default: () => 'CURRENT_TIMESTAMP' })
  createdAt!: Date;
}
